/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren
   
   The AttributeTypeLoader class creates a new instance of an
   AttributeType descendant, given the descendants class name.

   $Id: AttributeTypeLoader.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
   -------------------------------------------------------------------*/
package be.ulb.db;

import java.nio.*;
import java.lang.reflect.*;

import be.ulb.db.schema.*;

public class AttributeTypeLoader
{
    @SuppressWarnings("unchecked")
	public static AttributeType load(String className, int maxlength)
    {
	try {
	    //make sure the class is loaded into memory
	    Class attrtypeclass = Class.forName(className);

	    try {
		//try to construct the class with a constructor taking the maximum length
		Class [] cargs = { int.class };
		Constructor c = attrtypeclass.getConstructor(cargs);
		Object [] oargs = { new Integer(maxlength)};
		return (AttributeType) c.newInstance(oargs);
	    }
	    catch(NoSuchMethodException e) {
		//this attribute type does not take a maximum length - use the default parameter
		return (AttributeType) attrtypeclass.newInstance();
	    }
	}
	catch(Exception e) {
	    System.out.println("Error while creating AttributeType " + className + " with length " + maxlength);
	    e.printStackTrace();
	    System.exit(1);
	}

	return null;
    }
}
