/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren

   The BlockAddress class represents the address of a block.

   You should not create BlockAddresses directly, they should be read
   from blocks returned by the buffer manager when you allocate a new
   block or pin a block.

   $Id: BlockAddress.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
   -------------------------------------------------------------------*/
package be.ulb.db;

public class BlockAddress
{
    protected int blockoffset;
    
    public BlockAddress(int blockoffset)
    {
	this.blockoffset = blockoffset;
    }

    public int getBlockOffset()
    {
	return blockoffset;
    }

    /* Returns true if the current BlockAddress may represent a valid
     * block address */
    public boolean isValid()
    {
	return blockoffset >= 0; 
    }

    public boolean equals(Object o)
    {
	if (! (o instanceof BlockAddress))
	    return false;
	
	BlockAddress other = (BlockAddress) o;
	return other.blockoffset == this.blockoffset;
    }

    public int hashCode()
    {
	return blockoffset;
    }
    

    /* Represents a block address which is always invalid. Can be used
     * to denote End-Of-List in a linked list of blocks */
    public static final BlockAddress INVALIDADDR = new BlockAddress(-1);
}

