/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren

   The BlockFactory class provides capabilities to generate a Block
   given an in-memory buffer containing the block information, and its
   BlockAddress.

   BlockFactories are used by the Buffer Manager to link a memory
   buffer to the correct type of Java block. For instance when we want
   to read the block at BlockAddress addr into a MainBlock (a block
   occurring in a main file), we do:

   bm.pinBlock(addr, new MainBlockFactory())

   wich will return a MainBlock linked to the memory buffer which
   holds the contents of disk block addr. A BlockFactory is meant to
   be subclassed, a new BlockFactory should be created for every new
   kind of Java block. 

   $Id: BlockFactory.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
  -------------------------------------------------------------------*/
package be.ulb.db;

import java.nio.*;

public abstract class BlockFactory
{
    /* Subclasses should return a Java block object wrapping the
       buffer buff, containing the content of the disk block at
       address addr.  */
    public abstract Block create(ByteBuffer buff, BlockAddress addr);
}

