/*-------------------------------------------------------------------
   Authors: 2001-2003: Stijn Vansummeren

   The database class provides capabilities to:
   - Create a file for the database with a certain file size. 
   - Make Relation objects

   $Id: Database.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
 -------------------------------------------------------------------*/
package be.ulb.db;


import java.io.*;

import be.ulb.db.buffermanager.*;
import be.ulb.db.catalog.*;
import be.ulb.db.diskmanager.*;
import be.ulb.db.schema.*;

public class Database
{
    protected DiskManager dm;
    protected BufferManager bm;
    protected Catalog catalog;
    
    /** creates a new database with numblocks blocks of size
     * blocksize, which uses a buffer manager with numbuffer
     * buffers. It throws DiskManagerException if the database already
     * exists. */
    public Database(File file, int numblocks, int blocksize, int numbuffers)
	throws IOException, BufferManagerException, DiskManagerException
    {
	this.dm = new DiskManager(file, numblocks, blocksize);
	this.bm = new BufferManager(numbuffers, dm);
	this.catalog = new Catalog(bm,dm);
    }

    /** creates a new database with numblocks blocks of default
     * blocksize, which uses a buffer manager with numbuffer
     * buffers. It throws DiskManagerException if the database already
     * exists. */
    public Database(File file, int numblocks, int numbuffers)
	throws IOException, BufferManagerException, DiskManagerException
    {
	this.dm = new DiskManager(file, numblocks);
	this.bm = new BufferManager(numbuffers, dm);
	this.catalog = new Catalog(bm,dm);
    }

    /** Loads an existing database. The block size is read from the
     * database. Also allocates a buffermanager with numbuffer
     * buffers. It throws DiskManagerException if the database does not
     * exist. */
    public Database(File file, int numbuffers)
	throws FileNotFoundException, IOException, BufferManagerException, DiskManagerException 
    {
	this.dm = new DiskManager(file);
	this.bm = new BufferManager(dm.getBlockSize(), dm);
	this.catalog= new Catalog(bm, dm);
    }
    
    public Catalog getCatalog()
    {
	return catalog;
    }

    public BufferManager getBufferManager()
    {
	return bm;
    }

    public DiskManager getDiskManager()
    {
	return dm;
    }
}
