/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren

   The RecordIterator interface. It provides a means to iterate over
   all records in a block, a file, ...

   Note that the behaviour of an iterator is UNDEFINED if the
   underlying block, file, ... is modified (freed, records added or
   removed after the iterator has been opened, ...).

   $Id: RecordIterator.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
   -------------------------------------------------------------------*/
package be.ulb.db;



import java.util.*;
import java.io.*;

import be.ulb.db.buffermanager.*;
import be.ulb.db.diskmanager.*;
import be.ulb.db.schema.*;

public interface RecordIterator
{
    /* standard iterator stuff */
    public boolean hasNext();
    public Record next() throws NoSuchElementException , IOException,
				BufferManagerException, DiskManagerException;

    /* closes the attached resources. Calling other methods after a call to close() can fail */
    public void close();
    
    /* returns the RecordAddress of the current record. Throws
     * NoSuchElementException if there is no current record*/
    public RecordAddress getRecordAddress() throws NoSuchElementException;

    /* updates the current record. Throws NoSuchElementException if
     * there is no current record. Throws SchemaException if the
     * schema of rec differs from the record to be updated. */
    public void updateRecord(Record rec)
	throws SchemaException, BufferManagerException, DiskManagerException,
	       IOException, NoSuchElementException;
    
}
