/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren

   The ClockBufferReplacementPolicy class represents the clock
   replacement policy.

   $Id: ClockBufferReplacementPolicy.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
 -------------------------------------------------------------------*/
package be.ulb.db.buffermanager;

public class ClockBufferReplacementPolicy extends BufferReplacementPolicy
{
    protected boolean [] states;
    protected int current;
            
    public ClockBufferReplacementPolicy(int numbuffers)
    {
	super(numbuffers);
	states = new boolean[numbuffers];
	current = 0;
    }

    /* unpin the buffer: indicate that the user does not need the
     * buffer any more. Buffers with pincount = 0 are possible
     * candidates for replacements */
    public void unpin(int buffnum) throws BufferReplacementPolicyException
    {
	super.unpin(buffnum);
	states[buffnum] =  true; //indicate that we have recently used this buffer
    }

    /* free a buffer - should only be used when the buffer's content
       is also deallocated on disk.  Freed buffers are always eligble
       for replacement. */
    public void free(int buffnum) throws BufferReplacementPolicyException
    {
	super.free(buffnum);
	states[buffnum] = false; //immediate candidate for replacement
	current = buffnum; 
    }

    /* returns the buffer number which should be written back to disk
     * (if it's dirty) and whose content can then be reused. The
     * victims returned are never pinned. */
    public int pickVictim() throws BufferReplacementPolicyNoVictimException
    {
	int count = 0;
	int victim = -1;
	boolean found = false;
	boolean allpinned = true;
	
	/* view the pincount array as a circle */
	while(count < numbuffers && !found ) {
	    if (getPinCount(current) == 0) {
		allpinned = false;
		    
		/* do we have an eligble candidate for replacement ? */
		if (!states[current])
		    {
			victim = current;
			found = true;
		    }
		else 
		    /* this buffer becomes an eligble candidate the next time we come round */
		    states[current] = false;
	    }

	    current = (current + 1) % numbuffers;
	    count++;
	}

	if (found) return victim;
	
	/* we only have to traverse a second time if not all buffers
	 * are pinnend in the first round */
	if (!allpinned) {
	    count = 0;

	    /* cycle again - we will definitely find a victim */
	    while(count < numbuffers && !found ) {
		if (getPinCount(current) == 0) {
		    /* it is definetely eligable for replacement */
		    victim = current;
		    found = true;
		}

		current = (current + 1) % numbuffers;
		count++;
	    }

	    return victim;
	} else
	    /* after we have cycled the array twice, we always find a
	     * victim, unless all buffers are pinned - we do not have
	     * a candidate in that case */
	    throw new BufferReplacementPolicyNoVictimException();
    }
}

