/*-------------------------------------------------------------------
  Authors: 2003: Stijn Vansummeren

  Describes the schema of the records stored in the Attribute
  Catalog. This schema consists of the following fields:
  - the name of the relation
  - the name of the attribute
  - the type of the attribute (contains the class name of the AttributeType)
  - the maximum length of the attribute (i.e. for AttributeTypeString)
  - the offset of the attribute in the schema
  
  $Id: AttributeCatalogSchema.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
 -------------------------------------------------------------------*/
package be.ulb.db.catalog;

import be.ulb.db.schema.*;

public class AttributeCatalogSchema extends Schema
{
    public static final int MAXATTRNAMELENGTH = RelationCatalogSchema.MAXNAMELENGTH;
    public static final int MAXTYPELENGTH = 120;

    public static final String RELNAME = "relname";
    public static final String ATTRNAME = "attrname";
    public static final String TYPE = "type";
    public static final String LENGTH = "length";
    public static final String OFFSET = "offset";
	
    public AttributeCatalogSchema()
    {

	try {
	    String [] names =  {RELNAME, ATTRNAME, TYPE, LENGTH, OFFSET};
	    AttributeType [] types = {new AttributeTypeString(RelationCatalogSchema.MAXNAMELENGTH),
				      new AttributeTypeString(MAXATTRNAMELENGTH),
				      new AttributeTypeString(MAXTYPELENGTH),
				      new AttributeTypeInt(),
				      new AttributeTypeInt()};

	    initSchema(names, types);
	} catch(SchemaException e) {
	    e.printStackTrace();
	    System.exit(1); // it should not occur
	}
    }

    /* statically determine the offset of the attributes */
    public static final int relNameIndex = 0;
    public static final int attrNameIndex = 1;
    public static final int typeIndex = 2;
    public static final int lengthIndex = 3;
    public static final int offsetIndex = 4;
}
