/*-------------------------------------------------------------------
  Authors: 2003: Stijn Vansummeren

  Describes the schema of the records stored in the IndexAttr
  Catalog. This schema consists of the following fields:
  - the name of the relation
  - the ID of the index (must be unique)
  - the name of the attribute belonging to the index
  - the offset of the attribute inside the key schema
  
  $Id: IndexAttrCatalogSchema.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
 -------------------------------------------------------------------*/
package be.ulb.db.catalog;

import be.ulb.db.*;
import be.ulb.db.buffermanager.*;
import be.ulb.db.diskmanager.*;
import be.ulb.db.schema.*;

public class IndexAttrCatalogSchema extends Schema
{
    public static final String RELNAME = "relname";
    public static final String ID = "indexid";
    public static final String ATTRNAME = "attrname";    
    public static final String OFFSET = "offset";
	
    public IndexAttrCatalogSchema()
    {

	try {
	    String [] names =  {RELNAME, ID, ATTRNAME, OFFSET};
	    AttributeType [] types = {new AttributeTypeString(RelationCatalogSchema.MAXNAMELENGTH),
				      new AttributeTypeInt(),
				      new AttributeTypeString(AttributeCatalogSchema.MAXATTRNAMELENGTH),
				      new AttributeTypeInt()};
	    
	    initSchema(names, types);
	} catch(SchemaException e) {
	    e.printStackTrace();
	    System.exit(1); // it should not occur
	}
    }

    /* statically determine the offset of the attributes */
    public static final int relNameIndex = 0;
    public static final int idIndex = 1;
    public static final int attrNameIndex = 2;
    public static final int offsetIndex = 3;
}
