/*-------------------------------------------------------------------
  Authors: 2003: Stijn Vansummeren

  Describes the kind of indexes on a relation.
   This schema consists of the following fields:
  - the name of the relation
  - the ID of the index (must be unique)
  - the type of the index (contains the class name of the Index)  
  - the number of attributes in the index keyschema
  - the block address where the index can be found
  
  $Id: IndexCatalogSchema.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
 -------------------------------------------------------------------*/
package be.ulb.db.catalog;

import be.ulb.db.*;
import be.ulb.db.buffermanager.*;
import be.ulb.db.diskmanager.*;
import be.ulb.db.file.*;
import be.ulb.db.schema.*;

public class IndexCatalogSchema extends Schema
{
    public static final int MAXTYPELENGTH = 120;

    public static final String RELNAME = "relname";
    public static final String ID = "indexid";
    public static final String TYPE = "type";
    public static final String ATTRNUM = "attrnum";
    public static final String ADDR = "addr";

    public IndexCatalogSchema()
    {

	try {
	    String [] names =  {RELNAME, ID, TYPE, ATTRNUM, ADDR};
	    AttributeType [] types = {new AttributeTypeString(RelationCatalogSchema.MAXNAMELENGTH),
				      new AttributeTypeInt(),
				      new AttributeTypeString(MAXTYPELENGTH),
				      new AttributeTypeInt(),
				      new AttributeTypeBlockAddress()};
	    
	    
	    initSchema(names, types);
	} catch(SchemaException e) {
	    e.printStackTrace();
	    System.exit(1); // it should not occur
	}
    }

    /* statically determine the offset of the attributes */
    public static final int relNameIndex = 0;
    public static final int idIndex = 1;
    public static final int typeIndex = 2;
    public static final int attrNumIndex = 3;
    public static final int addrIndex = 4;
}
