/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren

   The DiskManagerFreeListBlock class is used by the DiskManager to
   create a linked list of free blocks. 

   $Id: DiskManagerFreeListBlock.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
 -------------------------------------------------------------------*/
package be.ulb.db.diskmanager;

import java.nio.*;

import be.ulb.db.*;
import be.ulb.db.schema.*;


public class DiskManagerFreeListBlock extends Block 
{
    //describes the records inside a DiskManagerFreeListBlock
    private static class LinkedBlockListSchema extends Schema
    {
	private static String PREV = "prev";
	private static String NEXT = "next";
    
	public LinkedBlockListSchema()
	{
	    try {
		String [] names =  {PREV, NEXT};
		AttributeType [] types = {new AttributeTypeBlockAddress(),new AttributeTypeBlockAddress() };
	    
		initSchema(names, types);
	    } catch(SchemaException e) {
		e.printStackTrace();
		//ignore since - it should not occur
	    }
	}

	/* statically determine the offset of the previous and next attributes */
	public static int prevIndex = 0;
	public static int nextIndex = 1;
    
    }
    
    private static Schema listschema = new LinkedBlockListSchema();
    private Record rec;
    
    /* The offsets of the bock where we put the previous and next address */
    public DiskManagerFreeListBlock(ByteBuffer buffer, BlockAddress addr)
    {
	super(buffer, addr);
	int oldLimit = buff.limit();
	buff.position(0);
	buff.limit(listschema.bytesize());

	/* connect the first listSchema.bytesize() bytes of the buffer
	   to rec. We can then write the block's header through the
	   record interface */
	try {
	    rec = new Record(listschema, buff.slice());
	}
	catch (SchemaException e)   {
	    e.printStackTrace();
	    System.exit(1); // it should not occur	    
	}

	buff.limit(oldLimit);
    }

    /* initialize a freshly allocated buffer. In particular we give *
       default values for the prev and next fields */
    public void initContents()
    {
	setNextBlockAddr(BlockAddress.INVALIDADDR);
    }

    public boolean isModified()
    {
	return true;
    }
    
    /* Sets the address of the next block in the list */
    public void setNextBlockAddr(BlockAddress next)
    {
	try {
	    rec.putBlockAddress(LinkedBlockListSchema.nextIndex, next);
	}
	catch(SchemaException e) {
	    e.printStackTrace();
	    System.exit(1); // it should not occur
	}
    }

    /* Gets the address of the next block in the list. */
    public BlockAddress getNextBlockAddr() 
    {
	BlockAddress addr = null;
	
	try {
	    addr = rec.getBlockAddress(LinkedBlockListSchema.nextIndex);
	}
	catch(SchemaException e) {
	    e.printStackTrace();
	    System.exit(1); // it should not occur	  
	}

	return addr;
    }

}

