/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren
   
   The AttributeType class is a base class used to represent the various
   field types that can occur in a schema.

   It supports methods to write instances belonging to a field type to
   a byte buffer, and to read instances from a byte buffer.

   $Id: AttributeType.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
   -------------------------------------------------------------------*/
package be.ulb.db.schema;

import java.nio.*;

public abstract class AttributeType 
{
    /* Returns true when the java object represents a valid instance of this fieldtype */
    public abstract boolean hasInstance(Object o);

    /* returns the number of bytes needed to save an instance of this
     * type */
    public abstract int bytesize();

    /* returns the maximum length of the values stored in an attribute
     * of this type (when applicable i.e. not for
     * integers). Subclasses (like AtrributeTypeString) having a
     * maximum length should override  */
    public int getLength()
    {
	return -1;
    }

    /* writes an instance of the field type to the byte buffer */
    public abstract void writeInstanceToByteBuffer(ByteBuffer buff, Object instance);

    /* reads an instance of the field type from a byte buffer */
    public abstract Object readInstanceFromByteBuffer(ByteBuffer buff);
}
