/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren
   
   AttributeTypeBlockAddress represents the field type used to store
   block addresses.

   $Id: AttributeTypeBlockAddress.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
  -------------------------------------------------------------------*/
package be.ulb.db.schema;

import java.nio.*;

import be.ulb.db.*;

public class AttributeTypeBlockAddress extends AttributeType
{
    /* A java object is a valid instance of this field type if it is a
     * BlockAddress */
    public boolean hasInstance(Object o)
    {
	return (o instanceof BlockAddress);
    }

    /* returns the size of a value in bytes */
    public int bytesize()
    {
	return 4; //normal integers fit into 4 bytes
    }


    /* writes an instance of the field type to the byte buffer. We
     * assume the bytebuffer's position and limit have been set
     * correctly to the start end end of this field */
    public void writeInstanceToByteBuffer(ByteBuffer buff, Object instance)
    {
	BlockAddress addr = (BlockAddress) instance;
	Integer i = new Integer(addr.getBlockOffset());
	buff.putInt(i.intValue());
    }

    /* reads an instance of the field type from a byte buffer.  We
     * assume the bytebuffer's position and limit have been set
     * correctly to the start end end of this field */
    public Object readInstanceFromByteBuffer(ByteBuffer buff)
    {
	return new BlockAddress(buff.getInt());
    }

    public boolean equals(Object o)
    {
	return (o instanceof AttributeTypeBlockAddress);
    }
}

