/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren
   
   AttributeTypeBoolean represent the field type "INT" that can occur in a
   schema.

   $Id: AttributeTypeBoolean.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
  -------------------------------------------------------------------*/
package be.ulb.db.schema;

import java.nio.*;
import java.lang.*;

public class AttributeTypeBoolean extends AttributeType
{
    public AttributeTypeBoolean()
    {
    }

    /* A java object is a valid instance of this field type if it is
     * an integer */
    public boolean hasInstance(Object o)
    {
	return (o instanceof Boolean);
    }

    /* returns the size of a value in bytes */
    public int bytesize()
    {
	return 1; //normal boolean fits into one byte
    }

    /* writes an instance of the field type to the byte buffer.  We
     * assume the bytebuffer's position and limit have been set
     * correctly to the start end end of this field */
    public void writeInstanceToByteBuffer(ByteBuffer buff, Object instance)
    {
	boolean bool = ((Boolean) instance).booleanValue();
	byte b = (byte) (bool ? 1 : 0);
	buff.put(b);
    }

    /* reads an instance of the field type from a byte buffer.  We
     * assume the bytebuffer's position and limit have been set
     * correctly to the start end end of this field */
    public Object readInstanceFromByteBuffer(ByteBuffer buff)
    {
	byte b = buff.get();
	return new Boolean(b != 0);
    }

    public boolean equals(Object o)
    {
	return (o instanceof AttributeTypeBoolean);
    }
    
}
