/*-------------------------------------------------------------------
   Authors: 2003: Stijn Vansummeren
   
   AttributeTypeRecordAddress represents the field type used to store
   record addresses.

   $Id: AttributeTypeRecordAddress.java,v 1.1.1.1 2005/09/26 08:19:41 stijn Exp $
  -------------------------------------------------------------------*/
package be.ulb.db.schema;

import java.nio.*;

import be.ulb.db.*;

public class AttributeTypeRecordAddress extends AttributeType
{
    private AttributeTypeBlockAddress blocktype = new AttributeTypeBlockAddress();

    /* A java object is a valid instance of this field type if it is a
     * RecordAddress */
    public boolean hasInstance(Object o)
    {
	return (o instanceof RecordAddress);
    }

    /* returns the size of a value in bytes */
    public int bytesize()
    {
	return 8; //size of a blockaddress + one integer to store the slot
    }


    /* writes an instance of the field type to the byte buffer. We
     * assume the bytebuffer's position and limit have been set
     * correctly to the start end end of this field */
    public void writeInstanceToByteBuffer(ByteBuffer buff, Object instance)
    {
	RecordAddress addr = (RecordAddress) instance;
	blocktype.writeInstanceToByteBuffer(buff, addr.getBlockAddress());
	Integer i = new Integer(addr.getRecordIndex());
	buff.putInt(i.intValue());
    }

    /* reads an instance of the field type from a byte buffer.  We
     * assume the bytebuffer's position and limit have been set
     * correctly to the start end end of this field */
    public Object readInstanceFromByteBuffer(ByteBuffer buff)
    {
	BlockAddress baddr = (BlockAddress) blocktype.readInstanceFromByteBuffer(buff);
	int slot = buff.getInt();
	return new RecordAddress(baddr, slot);
    }

    public boolean equals(Object o)
    {
	return (o instanceof AttributeTypeRecordAddress);
    }
}

